systemtools.StorageFormatManager
================================

.. abjad-lineage:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager

.. autoclass:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.compare
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.format_one_value
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_format_pieces
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_indentation_strings
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_input_argument_values
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_dictionary
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_values
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_dictionary
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_values
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_repr_format
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_keyword_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_positional_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_storage_format
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_name
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_qualified_class_name
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.is_instance

Bases
-----

- :py:class:`__builtin__.object <object>`

Static methods
--------------

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.compare
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.format_one_value
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_format_pieces
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_indentation_strings
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_input_argument_values
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_dictionary
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_values
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_dictionary
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_values
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_repr_format
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_keyword_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_positional_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_storage_format
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_name
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_qualified_class_name
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.is_instance
   :noindex:
